<?php

declare(strict_types=1);

use PhpCsFixer\Fixer\ArrayNotation\TrimArraySpacesFixer;
use PhpCsFixer\Fixer\CastNotation\CastSpacesFixer;
use PhpCsFixer\Fixer\ControlStructure\YodaStyleFixer;
use PhpCsFixer\Fixer\LanguageConstruct\IsNullFixer;
use PhpCsFixer\Fixer\Operator\BinaryOperatorSpacesFixer;
use PhpCsFixer\Fixer\Operator\NotOperatorWithSuccessorSpaceFixer;
use PhpCsFixer\Fixer\Phpdoc\NoSuperfluousPhpdocTagsFixer;
use SlevomatCodingStandard\Sniffs\Arrays\DisallowImplicitArrayCreationSniff;
use SlevomatCodingStandard\Sniffs\Classes\ClassConstantVisibilitySniff;
use SlevomatCodingStandard\Sniffs\Exceptions\DeadCatchSniff;
use SlevomatCodingStandard\Sniffs\Functions\UnusedParameterSniff;
use SlevomatCodingStandard\Sniffs\Functions\UselessParameterDefaultValueSniff;
use SlevomatCodingStandard\Sniffs\Namespaces\UnusedUsesSniff;
use SlevomatCodingStandard\Sniffs\Namespaces\UseFromSameNamespaceSniff;
use SlevomatCodingStandard\Sniffs\Namespaces\UselessAliasSniff;
use SlevomatCodingStandard\Sniffs\Whitespaces\DuplicateSpacesSniff;
use Symfony\Component\DependencyInjection\Loader\Configurator\ContainerConfigurator;
use Symplify\EasyCodingStandard\ValueObject\Option;

return static function (ContainerConfigurator $containerConfigurator): void {
    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/psr12.php');

    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/php71.php');

    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/clean-code.php');

    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/common/array.php');

    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/common/comments.php');

    $containerConfigurator->import(
        __DIR__ . '/vendor/symplify/easy-coding-standard/config/set/common/control-structures.php'
    );

    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/common/docblock.php');

    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/common/namespaces.php');

    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/common/spaces.php');

    $containerConfigurator->import(__DIR__ . '/vendor/symplify/easy-coding-standard/config/set/common/strict.php');

    $services = $containerConfigurator->services();

    $services->set(YodaStyleFixer::class)->call('configure', [
        [
            'equal'            => true,
            'identical'        => true,
            'less_and_greater' => false,
        ],
    ]);

    $services->set(CastSpacesFixer::class)->call('configure', [
        [
            'space' => 'single',
        ],
    ]);

    $services->set(BinaryOperatorSpacesFixer::class)->call('configure', [
        [
            'align_double_arrow' => true,
            'align_equals'       => true,
        ],
    ]);

    $services->set(IsNullFixer::class)->call('configure', [
        [
            'use_yoda_style' => true,
        ],
    ]);

    $services->set(DisallowImplicitArrayCreationSniff::class);

    $services->set(ClassConstantVisibilitySniff::class);

    $services->set(DeadCatchSniff::class);

    $services->set(UnusedParameterSniff::class);

    $services->set(UselessParameterDefaultValueSniff::class);

    $services->set(UnusedUsesSniff::class);

    $services->set(UseFromSameNamespaceSniff::class);

    $services->set(UselessAliasSniff::class);

    $parameters = $containerConfigurator->parameters();

    $parameters->set(Option::SKIP, [
        TrimArraySpacesFixer::class               => null,
        NotOperatorWithSuccessorSpaceFixer::class => null,
        DuplicateSpacesSniff::class               => null,
        UnusedParameterSniff::class               => null,
        NoSuperfluousPhpdocTagsFixer::class       => null,
    ]);
};
