<?php

declare(strict_types=1);

use PackageVersions\Versions;
use Shopware\Core\Framework\Plugin\KernelPluginLoader\StaticKernelPluginLoader;
use Shopware\Development\Kernel;
use Symfony\Component\Dotenv\Dotenv;

$autoLoadFile = __DIR__ . '/../../../../../vendor/autoload.php';
$classLoader  = require $autoLoadFile;
(new Dotenv(true))->load(__DIR__ . '/../../../../../.env');

$shopwareVersion = Versions::getVersion('shopware/platform');
$pluginLoader    = new StaticKernelPluginLoader($classLoader);
$cacheId         = 'default';

$kernel = new Kernel('dev', true, $pluginLoader, $cacheId, $shopwareVersion);

try {
    $kernel->boot();
} catch (\Doctrine\DBAL\Exception\DriverException $e) {}

$cacheDir = basename($kernel->getCacheDir());

$phpStanConfigDist = file_get_contents(__DIR__ . '/phpstan.neon.dist');

if ($phpStanConfigDist === false) {
    throw new RuntimeException('phpstan.neon.dist file not found');
}

// because the cache dir is hashed by Shopware, we need to set the PHPStan config dynamically
$phpStanConfig = str_replace('%SHOPWARE_CACHE_FOLDER%', $cacheDir, $phpStanConfigDist);

file_put_contents(__DIR__ . '/phpstan.neon', $phpStanConfig);
