<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Components;

use Doctrine\DBAL\Connection;
use Doctrine\DBAL\DBALException;
use NetInventors\NetiNextToolKit\Core\Content\PropertyGroup\Aggregate\Attribute\AttributeDefinition;
use Shopware\Core\Framework\Plugin\Context\InstallContext;
use Symfony\Component\DependencyInjection\ContainerInterface;

class Setup
{
    /**
     * @var InstallContext
     */
    protected $context;

    /**
     * @var ContainerInterface
     */
    protected $container;

    /**
     * Setup constructor.
     *
     * @param InstallContext     $context
     * @param ContainerInterface $container
     */
    public function __construct(InstallContext $context, ContainerInterface $container)
    {
        $this->context   = $context;
        $this->container = $container;
    }

    /**
     * @throws \Throwable
     */
    public function install(): void
    {
    }

    /**
     * @throws DBALException
     */
    public function uninstall(): void
    {
        $this->deleteTables();
    }

    /**
     * @throws DBALException
     */
    protected function deleteTables(): void
    {
        /** @var Connection $connection */
        $connection = $this->container->get(Connection::class);
        $connection->executeStatement('SET foreign_key_checks=0;');
        $connection->executeStatement('DROP TABLE IF EXISTS ' . AttributeDefinition::ENTITY_NAME);
        $connection->executeStatement('SET foreign_key_checks=1;');
    }
}
