<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Decorator;

use Shopware\Core\Content\Product\SalesChannel\Listing\AbstractProductListingRoute;
use Shopware\Core\Content\Product\SalesChannel\Listing\ProductListingRouteResponse;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Criteria;
use Shopware\Core\Framework\DataAbstractionLayer\Search\Filter\EqualsFilter;
use Shopware\Core\System\SalesChannel\SalesChannelContext;
use Symfony\Component\HttpFoundation\Request;

class ProductListingRouteDecorator extends AbstractProductListingRoute
{
    private AbstractProductListingRoute $mainService;

    public function __construct(
        AbstractProductListingRoute $mainService
    ) {
        $this->mainService = $mainService;
    }

    public function getDecorated(): AbstractProductListingRoute
    {
        return $this->mainService;
    }

    public function load(
        string              $categoryId,
        Request             $request,
        SalesChannelContext $context,
        Criteria            $criteria
    ): ProductListingRouteResponse {
        $criteria->addAssociation('properties.group');
        $criteria->getAssociation('properties')->addFilter(
            new EqualsFilter('group.netiToolKitAttribute.displayInListing', true)
        );

        return $this->mainService->load($categoryId, $request, $context, $criteria);
    }
}