<?php declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Service;

use Shopware\Core\PlatformRequest;
use Shopware\Core\System\SystemConfig\SystemConfigService;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RequestStack;

class PluginConfig
{
    public const CONFIG_DOMAIN = 'NetiNextToolKit.config';

    /**
     * @var array
     */
    private $config;

    public function __construct(
        SystemConfigService $systemConfig,
        RequestStack $requestStack
    ) {
        $this->loadConfig($systemConfig, $requestStack);
    }

    private function loadConfig(SystemConfigService $systemConfig, RequestStack $requestStack): void
    {
        $request        = $requestStack->getCurrentRequest();
        $salesChannelId = null;

        if ($request instanceof Request) {
            $salesChannelId = $request->attributes->get(PlatformRequest::ATTRIBUTE_SALES_CHANNEL_ID);
        }

        $this->config = $systemConfig->get(self::CONFIG_DOMAIN, $salesChannelId);
    }

    /**
     * @return bool
     */
    public function isActive(): bool
    {
        return $this->config['active'] ?? false;
    }
}
